@@ -1,9 +1,13 @@
-from os import device_encoding
+
+# needed for python > 3.8
+import os, sys
+if sys.version_info >= (3,8):
+    os.add_dll_directory(os.getcwd())
+
 import hid # type: ignore
 from .enums import (LedOptions, PlayerID,
                    PulseOptions, TriggerModes, Brightness)
 import threading
-import sys
 import winreg
 class pydualsense:
 
